      function [lat2,lon2,az2] = gdsdir ( lat1,lon1,az1,skm )
%
%         geodesic direct computation
%         from JRC 9-98 FTN routines
%         which were based on NOAA M10 routines
%         -- validated 1991 against Ohio State report of R.Rapp--
%
%
%
%    input:
%              lat1,lon2         begining latitude,longitude-  deg
%              az1               azimuth of ray from begin point - deg
%              skm               range in km
%
%    output:
%              lat2,lon2           end point -- deg
%              az2                 back azimuth -- deg
%

%         ------------------------------------------------------

%
%         Defaults to WGS 84
%                     Change via global variables if needed
%
%
%      ==============================================================
%                       ++ GLOBAL VARIABLES  ++
%
%       A_EARTH     if this and F_EARTH are present, defines ellipsoid
%       F_EARTH     "   "    "  A_EARTH  "    "         "      "     
%
%       FLAG_GDIST  0 converged, 1 error
%       ITER_GDIST  number of iterations used
%
     global   A_EARTH F_EARTH FLAG_GDIST ITER_GDIST
%
%    ================================================================
%   
%C
%C  -------------------------------
      TOL    = 5.0D-15;
      flag   =  0;
%C
%C------------------------------------------------------------------
%C
      PI        =   pi;
      true      =    1;
      false     =    0;
%
      FLAT1     =  lat1;
      FLON1     =  lon1;
      AZ1       =  az1;
      SKM       =  skm;
%
%
%         ------------------------------------------------------
%C
%C    FILL WITH WGS84 VALUES INITIALLY ON GEODETIC/GEOPHYSICAL
%C
%
%
%    -------------------------------------------------------
%
%
      RE      =   6378.137D00 ;
      FETH    =   0.335281066474D-2;
%
%              use global values if exist for ellipsoid
%
      tstell1 =   exist('A_EARTH');
      tstell2 =   exist('F_EARTH');
      if tstell1==1 &  tstell2==1, 
         szAE = size(A_EARTH);
         tstell3=max(szAE);
         if tstell3 > 0, 
            RE     = A_EARTH;
            FETH   = F_EARTH;
         end;
      end;
%
      EETH    =   8.18191908426D-2;
      ESETH   =   6.69437999013D-3;
%C
%C
      PIGDES    =   PI;
      FGDES     =   FETH;
      AGDES     =   1000.0D0*RE;
%C
%C
      PI       =   PIGDES;
      A        =   AGDES;
      F        =   FGDES;
%C
      TWOPI    =   2.0D0*PI;
      DTR      =   PI/180.0D0;
%C
%         ------------------------------------------------------
%C
      P1       =   DTR * FLAT1;
      E1       =   DTR * FLON1;
      A1       =   DTR * AZ1;
%C
      S        =   1000.0D0 * SKM;
%C
      ESQ      =   2.0D0 * F  - F*F;
%C
%C
%C     CONSTANTS OF THE ELLIPSOID
%C
      FINV=1.0D0/F;
%C
%C     START THE DIRECT PROBLEM
%C
      ELON1=-E1;
      FAZ=A1+PI;
%      IF(FAZ.GT.TWOPI) FAZ=FAZ-TWOPI;
      if FAZ > TWOPI , FAZ = FAZ - TWOPI; end;

      R=1.0D0-F;
      TU=R* sin(P1)/ cos(P1);
      SF=- sin(FAZ);
      CF=- cos(FAZ);
      BAZ=0.0D0;
%C
%      IF(CF.NE.0.0D0)BAZ= atan2(TU,CF)*2.0D0;
%%==      if abs(CF) > TOL , BAZ =  atan2( TU, CF) * 2.0D0; end;
      BAZ =  atan2( TU, CF) * 2.0D0; end;
%C
      CU=1.0D0/ sqrt(1.0D0+TU*TU);
      SU=TU*CU;
      SA=CU*SF;
      C2A=1.0D0-SA*SA;
      X=1.0D0+ sqrt((1.0D0/R/R-1.0D0)*C2A+1.0D0);
      X=(X-2.0D0)/X;
      CX=1.0D0-X;
      CX=(X*X/4.0D0+1.0D0)/CX;
      D=(0.375D0*X*X-1.0D0)*X;
      TU=S/R/A/CX;
      Y=TU;
%C
      KOUNT  = 0;
%C
%1     CONTINUE;
%    -----------------  iteration loop begins ---------------
%
      done = false;
      while ( ~ done)
%C
      KOUNT = KOUNT + 1;
%      IF ( KOUNT.GT. 40 ) GOTO 300;
%C
      SY= sin(Y);
      CY= cos(Y);
      CZ= cos(BAZ+Y);
      ER=CZ*CZ*2.0D0-1.0D0;
      CX=Y;
      X=ER*CY;
      Y=ER+ER-1.0D0;
      Y=TU+(((SY*SY*4.0D0-3.0D0)*Y*CZ*D/6.0D0+X)*D/4.0D0-CZ)*SY*D;
%
%      IF( abs(Y-CX).GT.0.5D-13) GOTO 1;
%
       test = abs(Y-CX);
       if test < 0.5d-13 , done=true; end;
       if KOUNT>30
             done=true;
             flag= 1;
       end;
%
       end;
%
%    ----------  end iteration loop --------------------
%C
%300   CONTINUE;
%C
      BAZ=CU*CY*CF-SU*SY;
      CX=R* sqrt(SA*SA+BAZ*BAZ);
      D=SU*CY+CU*SY*CF;
      P2= atan2(D,CX);
      CX=CU*CY-SU*SY*CF;
      X= atan2(SY*SF,CX);
      CX=((-3.0D0*C2A+4.0D0)/FINV+4.0D0)*C2A/FINV/16.0D0;
      D=((ER*CY*CX+CZ)*SY*CX+Y)*SA;
%C 
      ELON2=(1.0D0-CX)*D/FINV-X+ELON1;
%      IF(ELON2.GT.PI) ELON2=ELON2-TWOPI;
%      IF(ELON2.LE.-PI)ELON2=ELON2+TWOPI;
      if ELON2 > PI   , ELON2 = ELON2 - TWOPI; end;
      if ELON2 <= -PI , ELON2 = ELON2 + TWOPI; end;
      
      E2=-ELON2;
      BAZ= atan2(SA,BAZ);
%      IF(BAZ.LT.0.0D0)BAZ=BAZ+TWOPI;
      if BAZ < 0.0D0 ,  BAZ = BAZ + TWOPI; end;
%
      A2=BAZ+PI;
%      IF(A2.GT.TWOPI)A2=A2-TWOPI;
       if A2 > TWOPI , A2 = A2 - TWOPI; end;
%
%C
%900   CONTINUE;
%C
      FLAT2  = P2 / DTR;
      FLON2  = E2 / DTR;
      AZ2    = A2 / DTR;
%C      
      ITER_GDIST  = KOUNT;
      FLAG_GDIST  = flag;
%
      lat2  = FLAT2;
      lon2  = FLON2;
      az2   = AZ2;
%
      return;
