      function [re,radlat,radlon] =  radcur (lat)
%
%       radius curvature  function
%              
%         J.R. Clynch  10-98   from 1985 fortran
%
%   input:
%            lat = latitude vector -  geodetic latitude in deg
%
%   output:
%
%      re  = physical radius  (km for all radii)
%      radlat = radius for lat  dnorth = radlat*dlat
%      radlon = radius for lon  deast  = cos(lat)*radlon*dlon
%
%      rn = radlon  = radius normal to ellipse 
%                     terminated by minor (long variation) ( also Rnu)
%      rm = radlat  = meridianal radius of curvature ( lat variation)
%
%
%    As Default
%    Uses WGS 84  a = semi major axis  = 6378.137;
%                 f  = flattening      = 1/298.257223563;
%
%    GLOBAL variables can reset ellipsoid
%         A_EARTH   = a
%         F_EARTH   = f
%
%              both must be present as variables to be active
%
     global  A_EARTH  F_EARTH
%
%         ----------------------------------------------------------
%
      a = 6378.137;
      f = 1/298.257223563;
%
%              use global values if exist for ellipsoid
%
      tstell1 =   exist('A_EARTH');
      tstell2 =   exist('F_EARTH');
      if tstell1==1 &  tstell2==1, 
         szAE = size(A_EARTH);
         tstell3=max(szAE);
         if tstell3 > 0, 
            a      = A_EARTH;
            f      = F_EARTH;
         end;
      end;
%
%
      b    = a*(1.0-f);
      esq  = (1.0-b*b/(a*a));
      e    = sqrt(esq);
%
      dtr = pi/180.0;
%
      clat = cos(dtr*lat);
      slat = sin(dtr*lat);
%
      dsq  = 1.0-esq*slat.*slat;
      d    = sqrt(dsq);
%
%      rn  = radius normal to ellipse terminated by minor (long variation)
%      rm  = meridianal radius of curvature ( lat variation)
%
      rn   = a./d;
      rm   = rn*(1.0-esq)./dsq;
%
      rho  = rn.*clat;
      z    = (1.0-esq)*rn.*slat;
      r    = sqrt( rho.*rho+z.*z);
%
      re      = r;
      radlat  = rm;
      radlon  = rn;
%
      return;
