     function[latgd,lon,altkm] = xyzllh(x);
%
% Converts cartesian coordinates to lat-long-height 
%
%         J.R. Clynch  3-06 
%         based on other geodesy routines in set
%         most of which are based on Bomford, H+M
%
% Input
%
%    x  =  row vector  (km)
%
% Output
%    latgd = geodetic latitude (deg)
%    lon   = longitude in deg
%    altkm = altitude (ellipsoid height) in km

%         Defaults to WGS 84
%                     Change via global variables if needed
%
%
%      ==============================================================
%                       ++ GLOBAL VARIABLES  ++
%
%       A_EARTH     if this and F_EARTH are present, defines ellipsoid
%       F_EARTH     "   "    "  A_EARTH  "    "         "      "     
%
     global   A_EARTH F_EARTH
%
%    ================================================================
%   

% Function Body

     dtr = pi/180.;
     rtd = 180./pi;

%
%
      a       =   6378.137D00 ;
      feth    =   0.335281066474D-2;
%
%              use global values if exist for ellipsoid
%
      tstell1 =   exist('A_EARTH');
      tstell2 =   exist('F_EARTH');
      if tstell1==1 &  tstell2==1, 
         szAE = size(A_EARTH);
         tstell3=max(szAE);
         if tstell3 > 0, 
            a      = A_EARTH;
            feth   = F_EARTH;
         end;
      end;
%
      b      = a * ( 1.0 - feth );
      eccsq  = 2*feth - feth^2;
%

%              there is no close form solution, iterate
%              a set of eq, max 4 times.  Converges fast
%    
%              can get geocentric lat, lon easy, and lon same
%              but to convert lat, need altitude, and to get that
%              need latgd.... so looking at correct down direction...
%
%
%         --------------------------------------------
%
     x1 = x(:,1);
     x2 = x(:,2);
     x3 = x(:,3);

%   
     loni  = atan2(x2,x1) * rtd;

     ixm  =  loni<0;
     loni =  loni + 360.0 * ixm;
%
     psq  =  x1.^2 + x2.^2;
     rsq  =  psq + x3.^2;
     p    =  sqrt( psq );
     r    =  sqrt( rsq );
%
%         iterate, start with geocentric lat, and |x| - rearth
%                   (note up not really along radius vector)
%
     latgc  =  asin ( x3./r )*rtd;
     tangc  =  x3./p;
%
     altn   =  r - rearthc(latgc);
     latn   =  latgc;
%
     maxiter = 4;
     iter    = 0;
     done    = 0;
%
     while ~done
%
        slat =  sin(dtr*latn);
        Rn   =  a./sqrt( 1.0 - eccsq*slat.*slat);
%
        delta  =  eccsq*Rn.*slat;
        L      =  x3 + delta;
        Rnp    =  sqrt( psq + L.*L );
        h      =  Rnp - Rn;
%
%    now compute the latgd
%
       ratio  =  1.0 - ((eccsq*Rn) ./Rnp );
       tangd  =  tangc./ratio;
       latgdn =  rtd * atan( tangd );
%
       difang =  latgdn - latn;
       latn   =  latgdn;
%
       iter   = iter + 1;
       maxchg = max(max(abs(difang)));
       if maxchg <1.0E-8 ;  done = 1; end;
       if iter > maxiter ;  done = 1; end;
%
     end;
%
     latgd  = latgdn;
     altkm  = h;
     lon    = loni;
%
     return;
